from setuptools import setup
setup(name="packageharry",
version="0.1",
description="This is DHANUSH Smart Calculator",
long_description="This is smartest calculator work on ur sentence",
author="DHANUSH",
package=['PACKAGEDHANUSH'],
install_requires=[])